## Set working directory
setwd("~/Desktop/Palmisanoetal")

## Add libraries (you may need to install these first)
library(rgdal)
library(maptools)
library(devtools)
install_github("ahb108/rcarbon@30a97ef")
library(rcarbon)
## NB. At the time of writing, there have been some issues with source installations of R packages on (some but not all) Windows 7/10 machines (see https://github.com/hadley/devtools/issues/1479)

## Load data
ita <- read.csv("csv/ITA.csv", header=TRUE, stringsAsFactors=FALSE, encoding="UTF-8",na.strings=c("NA",""),strip.white=TRUE)


## Drop dates with NA values in the column CRA, with time range wider then needed, and with the value "shell" in the column Material 
mydates<-mydates[!is.na(mydates$CRA) & mydates$CRA<10000,] 
mydates<-mydates[mydates$Material!="shell" & mydates$Material!="shell (marine)" | is.na(mydates$Material),]
mydates<-mydates[mydates$CRA!=3955 & mydates$CRA!=3800 & mydates$CRA!=3740 & mydates$CRA!=3740 & mydates$CRA!=3704 & mydates$CRA!=3700 & mydates$CRA!=3635 | !is.na(mydates$LabID) & mydates$LabID!="OZC-173",]
## Query the number of sites
length(unique(mydates$SiteName))
       
## General SPD parameters
nsim <- 1000 # number of actual simulations (set to 5 for full demo)
ncores <- 1 # multi-core processing (set higher if available)
runm <- 50 #smoothing of SPDs
binh <- 100 #bin clustering
realstartBP <- 9000
realendBP <- 1000
bracket <- 1000
workingstartBP <- realstartBP+bracket
workingendBP <- realendBP-bracket
if (workingendBP<0){ workingendBP <- 0 }


## Global Time Series and Exponential Model ##
## Get calibration curve
calCurveFile <- paste(system.file("data", package="rcarbon"), "/intcal13.14c", sep="")
options(warn=-1)
calCurve <- readLines(calCurveFile, encoding="UTF-8")
calCurve <- calCurve[!grepl("[#]",calCurve)]
calCurve <- as.matrix(read.csv(textConnection(calCurve), header=FALSE, stringsAsFactors=FALSE))
options(warn=0)
colnames(calCurve) <- c("BP","CRA","Error","D14C","Sigma")
calCurve <- as.data.frame(calCurve)
calCurve <- calCurve[calCurve$BP >= realendBP & calCurve$BP < realstartBP,] 
calCurve$Hi <- calCurve$BP+calCurve$Error
calCurve$Low <- calCurve$BP-calCurve$Error
calCurve$RCRA <- reScale(calCurve$CRA)

## Calibrate dates (unnormalised for now)
alldates <- calibrate(ages=mydates$CRA, errors=mydates$Error, calCurves='intcal13', method="standard", normalised=FALSE, ncores=ncores, calMatrix=TRUE)
quickdates <- quickMarks(alldates)
## Example of how to plot just the second date in this series
## plot(alldates,2, calendar="BCAD")

## Summed probability distributions (normalised and not)
bins <- binPrep(sites=mydates$SiteName, ages=mydates$CRA, h=binh)
allspdn <- spd(x=alldates, bins=bins, timeRange=c(workingstartBP,workingendBP), datenormalised=TRUE, runm=runm)
allspd <- spd(x=alldates, bins=bins, timeRange=c(workingstartBP,workingendBP), datenormalised=FALSE, runm=runm)
## number of bins
length(unique(bins))

## Exponential model
set.seed(123)
expnull <- modelTest(alldates, errors=mydates$Error, bins=bins, nsim=nsim, runm=runm, timeRange=c(realstartBP+500,realendBP), model="exponential", method="standard", ncores=ncores, datenormalised=FALSE)

## Plot SPDs (Fig. 5 in the paper)
pdf(file="SPDresults.pdf", width=6, height=6.25)
layout(matrix(c(1,2,3,4), 4, 1, byrow=TRUE), widths=4.5, heights=c(1.65,0.15,1.65,2))
par(mar=c(0, 1, 1, 1)) #c(bottom, left, top, right)
ymax <- max(allspdn$grid$PrDens)
plot(allspdn, xlim=c(-7500,500), cal="BCAD", xaxt='n', yaxt='n')
abline(v=seq(-7500,500,500), lty="dotted", col="white")
text(x=-7400, y=0.00050, labels="a. All Dates (normalised)", font=2, cex=0.8, adj=c(0,0.7))
text(x=-7400, y=0.00045, labels=paste("n=",nrow(mydates),", sites=",length(unique(mydates$SiteName)),", bins=",length(unique(bins)),sep=""), font=1, cex=0.7, adj=c(0,0.7))
legend(x=-7400,y=0.00040, legend=c("SPD"), lty=c("solid","solid"), lwd=c(3,0.5,1), col=c("grey90","grey50"), bty="n", cex=0.7)
box()
par(mar=c(0, 1, 0, 1)) #c(bottom, left, top, right)
plot(allspdn, xlim=c(realstartBP,realendBP), xaxt='n', yaxt='n', fill.p="white")
ht=1
halfbw=5
ystart=0
for (a in 1:length(quickdates$qMed)){
  polygon(x=c(quickdates$qMed[a]-halfbw,quickdates$qMed[a]-halfbw,quickdates$qMed[a]+halfbw,quickdates$qMed[a]+halfbw,quickdates$qMed[a]-halfbw),y=c(ystart,ht,ht,ystart,ystart), border=NA, col=rgb(0,0,0,25,maxColorValue=255), lwd=0.5)
}
box()
par(mar=c(0, 1, 0, 1)) #c(bottom, left, top, right)
ymax <- max(allspd$grid$PrDens)
plot(allspd, xlim=c(-7500,500), cal="BCAD", xaxt='n', yaxt='n')
abline(v=seq(-7500,500,500), lty="dotted", col="white")
abline(v=seq(-7500,500,500), lty="dotted", col="white")
text(x=-7400, y=0.00028, labels="b. All Dates (not normalised)", font=2, cex=0.8, adj=c(0,0.7))
text(x=-7400, y=0.00025, labels=paste("n=",nrow(mydates),", sites=",length(unique(mydates$SiteName)),", bins=",length(unique(bins)),sep=""), font=1, cex=0.7, adj=c(0,0.7))
legend(x=-7400,y=0.00023, legend=c("SPD"), lty=c("solid"), lwd=c(3,0.5), col=c("grey90"), bty="n", cex=0.7)
text(x=-6750, y=0.000020, labels="Mesolithic",lty=c("solid"), col=c("brown"), font=2, cex=0.8, adj=c(0.5,-0.5))
segments(-7500,0.000020,-6000, lty="solid", col="brown", lwd=(0.5))
segments(-6000,0.000020,-6000,0.000010,lty="solid", col="brown", lwd=(0.5))
text(x=-4500, y=0.000020, labels="Neolithic",lty=c("solid"), col=c("blue"), font=2, cex=0.8, adj=c(0.5,-0.5))
segments(-6000,0.000020,-3000, lty="solid", col="blue", lwd=(0.5))
segments(-3000,0.000020,-3000,0.000010,lty="solid", col="blue", lwd=(0.5))
text(x=-5250, y=0.000020, labels="Early",lty=c("solid"), col=c("blue"), font=1, cex=0.6, adj=c(0.5,1.4))
segments(-4500,0.000020,-4500,0.000010,lty="solid", col="blue", lwd=(0.5))
text(x=-4000, y=0.000020, labels="Middle",lty=c("solid"), col=c("blue"), font=1, cex=0.6, adj=c(0.5,1.4))
segments(-3500,0.000020,-3500,0.000010,lty="solid", col="blue", lwd=(0.5))
text(x=-3250, y=0.000020, labels="Late",lty=c("solid"), col=c("blue"), font=1, cex=0.6, adj=c(0.5,1.4))
segments(-3000,0.000020,-3000,0.000010,lty="solid", col="blue", lwd=(0.5))
text(x=-2650, y=0.000020, labels="Eneolithic",lty=c("solid"), col=c("darkcyan"), font=2, cex=0.8, adj=c(0.5,-0.5))
segments(-3000,0.000020,-2300, lty="solid", col="darkcyan", lwd=(0.5))
segments(-2300,0.000020,-2300,0.000010,lty="solid", col="darkcyan", lwd=(0.5))
text(x=-1650, y=0.000020, labels="Bronze Age",lty=c("solid"), col=c("darkgreen"), font=2, cex=0.8, adj=c(0.5,-0.5))
segments(-2300,0.000020,-1000, lty="solid", col="darkgreen", lwd=(0.5))
segments(-1700,0.000020,-1700,0.000010,lty="solid", col="darkgreen", lwd=(0.5))
segments(-1300,0.000020,-1300,0.000010,lty="solid", col="darkgreen", lwd=(0.5))
segments(-1000,0.000020,-1000,0.000010,lty="solid", col="darkgreen", lwd=(0.5))
text(x=-2000, y=0.000020, labels="EBA",lty=c("solid"), col=c("darkgreen"), font=1, cex=0.6, adj=c(0.5,1.4))
text(x=-1500, y=0.000020, labels="MBA",lty=c("solid"), col=c("darkgreen"), font=1, cex=0.6, adj=c(0.5,1.4))
text(x=-1150, y=0.000020, labels="LBA",lty=c("solid"), col=c("darkgreen"), font=1, cex=0.6, adj=c(0.5,1.4))
text(x=-800, y=0.000020, labels="Iron Age",lty=c("solid"), col=c("darkorange"), font=2, cex=0.8, adj=c(0.5,-0.5))
segments(-1000,0.000020,-600, lty="solid", col="darkorange", lwd=(0.5))
segments(-600,0.000020,-600,0.000010,lty="solid", col="darkorange", lwd=(0.5))
text(x=-50, y=0.000020, labels="Roman Period",lty=c("solid"), col=c("red"), font=2, cex=0.8, adj=c(0.5,-0.5))
segments(-600,0.000020, 500, lty="solid", col="red", lwd=(0.5))
segments(500,0.000020,500,0.000010,lty="solid", col="red", lwd=(0.5))
text(x=-6750, y=0.000055, labels="Hunther-gatherers",lty=c("solid"), col=c("brown"), srt=90, font=1, cex=0.7, adj=c(0,0.5))
text(x=-5800, y=0.000070, labels="Introduction of farming",lty=c("solid"), col=c("blue"), srt=90, font=1, cex=0.7, adj=c(0,0.5))
text(x=-3300, y=0.000050, labels="Intensification and specialisation",lty=c("solid"), col=c("blue"),font=1, srt=90, cex=0.7, adj=c(0,0.5))
text(x=-3150, y=0.000070, labels="of agrarian economies",lty=c("solid"), col=c("blue"),font=1, srt=90, cex=0.7, adj=c(0,0.5))
text(x=-2400, y=0.000070, labels="Emergence of social hierarchy",lty=c("solid"), col=c("darkcyan"),font=1, srt=90, cex=0.7, adj=c(0,0.5))
text(x=-1150, y=0.000070, labels="Proto-urban centres",lty=c("solid"), col=c("darkgreen"),font=1, srt=90, cex=0.7, adj=c(0,0.5))
text(x=-800, y=0.000070, labels="City-States",lty=c("solid"), col=c("darkorange"),font=1, srt=90, cex=0.7, adj=c(0,0.5))
text(x=-250, y=0.000070, labels="Republic",lty=c("solid"), col=c("red"),font=1, srt=90, cex=0.7, adj=c(0,0.5))
text(x=250, y=0.000070, labels="Empire",lty=c("solid"), col=c("red"),font=1, srt=90, cex=0.7, adj=c(0,0.5))
box()
par(mar=c(4, 1, 0, 1)) #c(bottom, left, top, right)
ymax <- max(expnull$result$PrDens)*1.1
plot(expnull, ylim=c(0,ymax), xlim=c(-7500,500), cal="BCAD", drawaxes=FALSE)
lines(expnull$fit$calBP,expnull$fit$PrDens, col="black", lty="dashed", lwd=0.5)
abline(v=seq(-7500,500,500), lty="dotted", col="white")
legend(x=-5500, y=0.00031, legend=c("SPD (dates not normalised)","Exponential Model", "95% MC envelope","positive deviation","negative deviation"),col=c(1, "black","lightgrey",rgb(0.7,0,0,0.2),rgb(0,0,0.7,0.2)), lty=c(1,2,1,1,1), lwd=c(0.5,0.5,5,5,5), cex=0.6, bty='n', bg="white", title="")
text(x=-5500, y=0.00032, labels="c. Exponential Fit", font=2, cex=0.7, adj=c(0,0.7))
text(x=-5500, y=0.00020, cex=0.6, adj=c(0,0.7), labels=substitute(paste(italic(p), "=", x, sep=""), list(x=round(expnull$pval,4))))
box()
xticks <- seq(-7500,500,500)
axis(side=1, at=xticks, labels=xticks, las=2, cex.axis=0.8)
dev.off()





