## Set working directory
setwd("~/Desktop/Palmisanoetal")
library(rgdal)
library(maptools)

## Load data
sites <- readOGR("shp/sites.shp", layer="sites")
sites <- sites@data #just use the attribute table only

## Create time blocks (200 yrs) and new columns
blockwidth <- 200
brks <- seq(-10000,1200,by=blockwidth)
mids <- seq(min(brks)+(blockwidth/2),max(brks)-(blockwidth/2),by=blockwidth)
newcolumns <- paste(brks[1:(length(brks)-1)],"start",sep="")

## Create new tables for storing results
aoristicweights <- siteareasums <- sitecounts <- sites
sitecounts[newcolumns] <- NA #add new columns
sitecounts <- sitecounts[,newcolumns] #drop all other columns
aoristicweights[newcolumns] <- NA #add new columns
aoristicweights <- aoristicweights[,newcolumns]#drop all other columns
siteareasums[newcolumns] <- NA #add new columns
siteareasums <- siteareasums[,newcolumns] #drop all other columns

## Calculate the duration of each site occupation phase
sites$Duration <- sites$EndDate - sites$StartDate

## Generate histogram showing the frequency of site-phases per time-span (Fig. 2 in the paper) 
hist(sites$Duration, cex.axis=0.75, xlab="Site Date Range in Years", ylab="Site Count", main="", breaks=30, col="black")
dev.print(device=pdf, "sitedateranges.pdf")

## Loop through and update timeblocks for each site
for (a in 1:nrow(sites)){
    cat(paste(a,"; ",sep="")) 
    sitestart <- sites$StartDate[a]
    siteend <- sites$EndDate[a]
    siteyears <- seq(sitestart,siteend,by=1)
    siteyearshist <- hist(siteyears, breaks=brks, plot=FALSE) 
    timewts <- siteyearshist$counts/blockwidth
    sitecounts[a,] <- timewts #ordinary counts (but timeblock proportional)
    aoristicweights[a,] <- timewts/sum(timewts) #aoristic weights
    siteareasums[a,] <- timewts*sites$SizeHa[a] #total site area
 }

## Randomised Start Dates and Duration ##
## Randomised start date of site occupation phase (uniform). A sites duration randomly generated from a normal distribution with a mean of 200 years and a standard deviations of 50 years is added to the drawn date
meanDuration <- 200 # mean of randomised site duration
minDuration <- 10
sdDuration <- 50 # standard deviation
sitesdf<-sites
nsim <- 1000 # number of simulations for generating a 95% confidence envelope
simdf <- as.data.frame(matrix(ncol=length(newcolumns), nrow=nsim))
colnames(simdf) <- newcolumns
## First loop to create site durations.
for (b in 1:nsim){
    cat(paste(b,"; ",sep="")) 
    tmpsitecounts <- sitecounts
    tmpsitecounts[] <- NA #blank place to put counts
    sitedur <- rnorm(n=nrow(sitesdf),meanDuration,sdDuration)
    while (any(sitedur<minDuration)){
        sitedur[sitedur<minDuration] <- rnorm(n=length(sitedur[sitedur<minDuration]),meanDuration,sdDuration) # enforce truncation at minDuration
    }
}
## Second loop to count results.
for (b in 1:nsim){
    cat(paste(b,"; ",sep=""))
    for (a in 1:nrow(sitesdf)){
        if (sitedur[a]>=sitesdf$Duration[a]){
            sitestart <- sitesdf$StartDate[a]
            siteend <- sitesdf$EndDate[a]
        } else {
            sitestart <- round(runif(1,min=sitesdf$StartDate[a],max=sitesdf$EndDate[a]-sitedur[a]),0)
            siteend <- round(sitestart+sitedur[a])
        }
        siteyears <- seq(sitestart,siteend,by=1)
        siteyearshist <- hist(siteyears, breaks=brks, plot=FALSE) 
        tmpsitecounts[a,] <- siteyearshist$counts/blockwidth
    }
    simdf[b,] <- colSums(tmpsitecounts, na.rm=TRUE)
}

## Randomised Start Dates and Duration, SPD Weighted ##
## Randomised start date of site occupation phase (uniform) weighted by SPD of radiocarbon dates. 
load("rda/spd_unnorm.RData") # load vector of SPD of calibrated unnormalised radiocarbon dates
meanDuration <- 200
minDuration <- 10
sdDuration <- 50
sitesdf<-sites
nsim <- 1000
simdf_spd <- as.data.frame(matrix(ncol=length(newcolumns), nrow=nsim))
colnames(simdf_spd) <- newcolumns
## First loop to create site durations.
for (b in 1:nsim){
  cat(paste(b,"; ",sep="")) 
  tmpsitecounts <- sitecounts
  tmpsitecounts[] <- NA #blank place to put counts
  sitedur <- rnorm(n=nrow(sitesdf),meanDuration,sdDuration)
  while (any(sitedur<minDuration)){
    sitedur[sitedur<minDuration] <- rnorm(n=length(sitedur[sitedur<minDuration]),meanDuration,sdDuration) # enforce truncation at minDuration
  }}
## Second loop to count results.
for (b in 1:nsim){
  cat(paste(b,"; ",sep=""))
  for (a in 1:nrow(sitesdf)){
    if (sitedur[a]>=sitesdf$Duration[a]){
      sitestart <- sitesdf$StartDate[a]
      siteend <- sitesdf$EndDate[a]
    } else {
      spd_unnorm1<-subset(spd_unnorm,spd_unnorm$BCAD>=sites$StartDate[a] & spd_unnorm$BCAD<=sites$EndDate[a])
      spd_unnorm2<-spd_unnorm1$PrDens/sum(spd_unnorm1$PrDens)
      x<-seq(min(spd_unnorm1$BCAD),max(spd_unnorm1$BCAD),1)
      sitestart<-sample(x, size = 1, replace = TRUE, prob = spd_unnorm2)-sitedur[a] 
      siteend <-(sitestart+sitedur[a])
    }
    siteyears <- seq(sitestart,siteend,by=1)
    siteyearshist <- hist(siteyears, breaks=brks, plot=FALSE) 
    tmpsitecounts[a,] <- siteyearshist$counts/blockwidth
    # tmpsitecounts[tmpsitecounts[,]>0.005]<-1 # tranformation in order to avoid values proportional to time block for sites count
    # tmpsitecounts[tmpsitecounts[,]==0.005]<-0
  }
  simdf_spd[b,] <- colSums(tmpsitecounts, na.rm=TRUE)
}

## Summarise data
sitecounts[sitecounts[,]>0.005]<-1 # tranformation in order to avoid values proportional to time block for sites count
sitecounts[sitecounts[,]==0.005]<-0 # tranformation in order to avoid values proportional to time block for sites count
siteBlockSumCounts <- colSums(sitecounts)
siteBlockSumWeights <- colSums(aoristicweights)
siteareasums<-sitecounts*sites$SizeHa # trasnformation in order to avoid values proportional to time block for sites size. WARNING: The sitecounts parameter inputted here is the one created with the two optional strings added above.
siteBlockAreaSums <- colSums(siteareasums)
funhi <- function(x){ quantile(x, probs=0.975) } # function defining upper limit of 95% confidence envelope 
funlo <- function(x){ quantile(x, probs=0.025) } # function defining lower limit of 95% confidence envelope
hicount <- apply(simdf,2,funhi) # upper limit of 95% confidence envelope of randomised start date of sites 
lowcount <- apply(simdf,2,funlo) # lower limit of 95% confidence envelope of randomised start date of sites 
medcount <- apply(simdf,2,median) # median of 95% confidence envelope of randomised start date of sites 
hicount_spd <- apply(simdf_spd,2,funhi) # upper limit of 95% confidence envelope of SPD weighted randomised start date of sites 
lowcount_spd <- apply(simdf_spd,2,funlo) # lower limit of 95% confidence envelope of SPD weighted randomised start date of sites 
medcount_spd <- apply(simdf_spd,2,median) # median of 95% confidence envelope of SPD weighted randomised start date of sites

## Plot settlement data proxies (Fig.6 in the paper)
prehistplotstart <- -7000
prehistplotend <- -800
prehistplotstart <- floor(prehistplotstart/blockwidth)*blockwidth
prehistplotend <- ceiling(prehistplotend/blockwidth)*blockwidth
prehistplotstarti <- which(newcolumns==paste(prehistplotstart,"start",sep=""))
prehistplotendi <- which(newcolumns==paste(prehistplotend,"start",sep=""))
xticklabs <- seq(-7500,1000,by=500)
xticklabshort <- seq(-8000,-1000,by=500)
dev.new(device=pdf, width=7, height=4)
par(mfrow=c(1,2))
par(mar=c(3, 3, 1,0.5)) #c(bottom, left, top, right)
plot(siteBlockAreaSums~mids, col="red", cex.axis=0.5, xaxt="n", type="l", xlab="", xlim=c(-7500,250))
lines(mids, siteBlockSumWeights, lty="dotted", col="black")
lines(mids, siteBlockSumCounts, lty="solid", col="black")
lines(mids, siteBlockAreaSums, col="red")
polygon(x=c(mids,rev(mids)), y=c(hicount_spd,rev(lowcount_spd)), col=rgb(0,0,1,0.3), border=NA)
polygon(x=c(mids,rev(mids)), y=c(hicount,rev(lowcount)), col=rgb(128, 128, 128,alpha=120, maxColorValue=255), border=NA)
legend("topleft", legend=c("raw count (y-axis)","aoristic weight","randomised duration", "randomised SPD weighted duration","total area"), lty=c("solid","dotted","solid","solid","solid"), lwd=c(1,1,3,3,1), col=c("black","black","grey75","blue","red"), bty="n", cex=0.6)
axis(side=1, at=xticklabs, cex.axis=0.5, las=2)
mtext("a",1, 1, adj=-0.1, font=2, cex=0.75)
par(mar=c(3, 2, 1, 0.5)) #c(bottom, left, top, right)
plot(siteBlockSumCounts[prehistplotstarti:prehistplotendi]~mids[prehistplotstarti:prehistplotendi], cex.axis=0.5, xaxt="n", type="l", xlab="", xlim=c(prehistplotstart,prehistplotend), ylim=c(0,max(siteBlockSumCounts[prehistplotstarti:prehistplotendi])))
polygon(x=c(mids,rev(mids)), y=c(hicount_spd,rev(lowcount_spd)), col=rgb(0,0,1,0.3), border=NA)
lines(mids, medcount_spd, col="blue")
polygon(x=c(mids,rev(mids)), y=c(hicount,rev(lowcount)), col=rgb(128, 128, 128,alpha=120, maxColorValue=255), border=NA)
lines(mids, medcount, col="grey38")
lines(mids, siteBlockSumWeights, lty="dotted", col="black", lwd=1)
lines(mids, siteBlockAreaSums, col="red")
axis(side=1, at=xticklabshort, cex.axis=0.5, las=2)
mtext("b",1, 1, adj=-0.05, font=2, cex=0.75)
dev.print(device=pdf, "siteseries.pdf")

##  Normalise all proxies between 7000-800 BC ##
## SPD of radiocarbon dates
x<-c(spd_unnorm[1051:7251,2])
spd<-((x-min(x))/(max(x) - min(x))) #x-values
spdX<-spd_unnorm[1051:7251,"BCAD"] #y-values
## Sites raw count
count<-siteBlockSumCounts[16:46] # make the vectors having the same length of spd
x<-count
siteBlockSumCounts_norm<-((x-min(x))/(max(x) - min(x)))
## Summed estimated settlement sizes
area<-siteBlockAreaSums[16:46]
x<-area
siteBlockAreaSums_norm<-((x-min(x))/(max(x) - min(x)))
## Aoristic weight
aoristic<-siteBlockSumWeights[16:46]
x<-aoristic
siteBlockSumWeights_norm<-((x-min(x))/(max(x) - min(x)))

## Normalise randomised start dates of sites
simdf_norm<-simdf 
simdf_norm[,]<-NA
for (a in 1:nrow(simdf_norm)){
    cat(paste(a,"; ",sep=""))
    x<-simdf[a,]
    tmp_norm<-test <- ((x-min(x))/(max(x) - min(x))) 
    simdf_norm[a,] <- tmp_norm    
}                                                         
simdf_norm[is.na(simdf_norm)] <- 0      
funhi <- function(x){ quantile(x, probs=0.975) }         
funlo <- function(x){ quantile(x, probs=0.025) }          
hicount_norm <- apply(simdf_norm,2,funhi)                 
lowcount_norm <- apply(simdf_norm,2,funlo)                
medcount_norm <- apply(simdf_norm,2,median)               
x <- medcount_norm[16:46]                                   
medcount_norm <- ((x-min(x))/(max(x) - min(x)))             
x <- hicount_norm[16:46]                                    
hicount_norm <- ((x-min(x))/(max(x) - min(x)))              
x <- lowcount_norm[16:46]                                   
lowcount_norm <- ((x-min(x))/(max(x) - min(x)))             

## Normalise SPD wighted randomised start dates of sites
simdf_spd_norm <- simdf_spd                                 
simdf_spd_norm[,] <- NA                                     
for (a in 1:nrow(simdf_spd_norm)){                       
    cat(paste(a,"; ",sep=""))                                   
    x <- simdf_spd[a,]                                        
    tmp_norm<-test <- ((x-min(x))/(max(x) - min(x)))        
    simdf_spd_norm[a,] <- tmp_norm                                
}                                                         
simdf_spd_norm[is.na(simdf_norm)] <- 0                     
hicount_spd_norm <- apply(simdf_spd_norm,2,funhi)         
lowcount_spd_norm <- apply(simdf_spd_norm,2,funlo)        
medcount_spd_norm <- apply(simdf_spd_norm,2,median)       
x <- medcount_spd_norm[16:46]                               
medcount_spd_norm <- ((x-min(x))/(max(x) - min(x)))         
x <- hicount_spd_norm[16:46]                               
hicount_spd_norm <- ((x-min(x))/(max(x) - min(x)))           
x <- lowcount_spd_norm[16:46]                               
lowcount_spd_norm <- ((x-min(x))/(max(x) - min(x)))          

## Plot normalised proxies (Fig.7 in the paper)
blockwidth <- 200
brks <- seq(-7000,-800,by=blockwidth)
mids <- seq(min(brks)+(blockwidth/2),max(brks)-(blockwidth/2),by=blockwidth)
newcolumns <- paste(brks[1:(length(brks)-1)],"start",sep="")
prehistplotstart <- -7000
prehistplotend <- -800
xticklabshort <- seq(-7000,-800,by=200)
prehistplotstart <- floor(prehistplotstart/blockwidth)*blockwidth
prehistplotend <- ceiling(prehistplotend/blockwidth)*blockwidth
prehistplotstarti <- 1 
prehistplotendi <- 31 
plot(siteBlockSumCounts_norm[prehistplotstarti:prehistplotendi]~mids[prehistplotstarti:prehistplotendi], cex.axis=0.5, xaxt="n", type="l", xlab="", xlim=c(prehistplotstart,prehistplotend), ylim=c(0,max(siteBlockSumCounts_norm[prehistplotstarti:prehistplotendi])))
polygon(x=c(mids,rev(mids)), y=c(hicount_spd_norm,rev(lowcount_spd_norm)), col=rgb(0,0,1,0.3), border=NA)
lines(mids, medcount_spd_norm, col="blue")
polygon(x=c(mids,rev(mids)), y=c(hicount_norm,rev(lowcount_norm)), col=rgb(128, 128, 128,alpha=120, maxColorValue=255), border=NA)
lines(mids, medcount_norm, col="grey38")
lines(mids, siteBlockSumWeights_norm, lty="dotted", col="black")
lines(mids, siteBlockAreaSums_norm, col="red")
lines(spdX,spd, col="green")
legend("topleft", legend=c("raw count (y-axis)","aoristic weight","randomised duration", "randomised SPD weighted duration","total area", "SPD of radiocarbon dates"), lty=c("solid","dotted","solid","solid","solid","solid"), lwd=c(1,1,3,3,1,1), col=c("black","black","grey75","blue","red","green"), bty="n", cex=0.6)
axis(side=1, at=xticklabshort, cex.axis=0.5, las=2)
dev.print(device=pdf, "siteseries_comparison.pdf", height=5, width=8)

## Correlations ##
## Set-up
x<-c(spd_unnorm[52:7251,2])
spd<-colSums(matrix( x, nrow = 200, ncol = 36))
count<-siteBlockSumCounts[11:46] 
area<-siteBlockAreaSums[11:46]
aorist<-siteBlockSumWeights[11:46]
random<-medcount[11:46]
random_spd<-medcount_spd[11:46]
myproxies<-data.frame(cbind(count,area,aorist,random,random_spd,spd))
cor_results<-cor(myproxies[,1:6], method="pearson")
## Plot correlations as a heat map (Fig.8 in the paper)
library(gplots)
cor_results <- round(cor_results,digits=2)
cor_results[upper.tri(cor_results,diag=FALSE)] <- 0
map <- heatmap.2(cor_results, main="Pearson's correlation", cellnote = cor_results, notecol="black", density.info="none", trace="none", margins=c(9,12), col=rev(heat.colors(256)), dendrogram="none", Colv = "FALSE", revC = "TRUE")
dev.print(device=pdf, file="heatmap.pdf")

